Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code | Sign in
(1307)

Unified Diff: src/lte/model/epc-x2.h

Issue 328170043: NS-3 GSoC 2017 LTE CA handover milestone 2 and 3
Patch Set: NS-3 GSoC 2017 LTE CA handover milestone 2 and 3 Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Please Sign in to add in-line comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/lte/model/epc-sgw-pgw-application.cc ('k') | src/lte/model/epc-x2.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/lte/model/epc-x2.h
===================================================================
--- a/src/lte/model/epc-x2.h
+++ b/src/lte/model/epc-x2.h
@@ -72,10 +72,10 @@
/**
* Constructor
*
* \param localCellId local cell ID
* \param remoteCellId remote cell ID
*/
- X2CellInfo (uint16_t localCellId, uint16_t remoteCellId);
+ X2CellInfo (std::vector<uint16_t> localCellIds, std::vector<uint16_t> remoteCellIds);
virtual ~X2CellInfo (void);
/**
@@ -86,8 +86,8 @@
X2CellInfo& operator= (const X2CellInfo &);
public:
- uint16_t m_localCellId; ///< local cell ID
- uint16_t m_remoteCellId; ///< remote cell ID
+ std::vector<uint16_t> m_localCellIds; ///< local cell IDs
+ std::vector<uint16_t> m_remoteCellIds; ///< remote cell IDs
};
@@ -135,11 +135,11 @@
* Add an X2 interface to this EPC X2 entity
* \param enb1CellId the cell ID of the current eNodeB
* \param enb1X2Address the address of the current eNodeB
* \param enb2CellId the cell ID of the neighbouring eNodeB
* \param enb2X2Address the address of the neighbouring eNodeB
*/
void AddX2Interface (uint16_t enb1CellId, Ipv4Address enb1X2Address,
- uint16_t enb2CellId, Ipv4Address enb2X2Address);
+ std::vector<uint16_t> enb2CellIds, Ipv4Address enb2X2Address);
/**
« no previous file with comments | « src/lte/model/epc-sgw-pgw-application.cc ('k') | src/lte/model/epc-x2.cc » ('j') | no next file with comments »
@@ -72,10 +72,10 @@
* Constructor
*
- * \param localCellId local cell ID
- * \param remoteCellId remote cell ID
+ * \param localCellId local cell IDs
+ * \param remoteCellId remote cell IDs
*/
@@ -135,11 +135,11 @@
* \param enb1CellId the cell ID of the current eNodeB
* \param enb1X2Address the address of the current eNodeB
- * \param enb2CellId the cell ID of the neighbouring eNodeB
+ * \param enb2CellIds the cell IDs of the neighbouring eNodeB
* \param enb2X2Address the address of the neighbouring eNodeB
*/

Powered by Google App Engine
RSS Feeds Recent Issues | This issue
This is Rietveld f62528b